Learn R Programming

ammistability (version 0.1.1)

FA.AMMI: Stability Measure Based on Fitted AMMI Model

Description

FA.AMMI computes the Stability Measure Based on Fitted AMMI Model (FA) (Raju, 2002) considering all significant interaction principal components (IPCs) in the AMMI model. Using FA, the Simultaneous Selection Index for Yield and Stability (SSI) is also calculated according to the argument ssi.method.

Usage

FA.AMMI(model, n, alpha = 0.05, ssi.method = c("farshadfar", "rao"),
  a = 1)

Arguments

model

The AMMI model (An object of class AMMI generated by AMMI).

n

The number of principal components to be considered for computation. The default value is the number of significant IPCs.

alpha

Type I error probability (Significance level) to be considered to identify the number of significant IPCs.

ssi.method

The method for the computation of simultaneous selection index. Either "farshadfar" or "rao" (See SSI).

a

The ratio of the weights given to the stability components for computation of SSI when method = "rao" (See SSI).

Value

A data frame with the following columns:

FA

The FA values.

SSI

The computed values of simultaneous selection index for yield and stability.

rFA

The ranks of FA values.

rY

The ranks of the mean yield of genotypes.

means

The mean yield of the genotypes.

The names of the genotypes are indicated as the row names of the data frame.

Details

The Stability Measure Based on Fitted AMMI Model () is computed as follows:

Where, is the number of significant IPCs (number of IPC that were retained in the AMMI model via F tests); is the singular value for th IPC and correspondingly is its eigen value; and is the eigenvector value for th genotype.

When is replaced by 1 (only first IPC axis is considered for computation), then the parameter can be estimated (Zali et al., 2012).

When is replaced by 2 (only first two IPC axes are considered for computation), then the parameter can be estimated (Zali et al., 2012).

When is replaced by (All the IPC axes are considered for computation), then the parameter estimated is equivalent to Wricke's ecovalence () (Wricke, 1962; Zali et al., 2012).

References

wricke_method_1962ammistability

raju_study_2002ammistability

zali_evaluation_2012ammistability

See Also

AMMI, SSI

Examples

Run this code
# NOT RUN {
library(agricolae)
data(plrv)

# AMMI model
model <- with(plrv, AMMI(Locality, Genotype, Rep, Yield, console = FALSE))

# ANOVA
model$ANOVA

# IPC F test
model$analysis

# Mean yield and IPC scores
model$biplot

# G*E matrix (deviations from mean)
array(model$genXenv, dim(model$genXenv), dimnames(model$genXenv))

# With default n (N') and default ssi.method (farshadfar)
FA.AMMI(model)

# With n = 4 and default ssi.method (farshadfar)
FA.AMMI(model, n = 4)

# With default n (N') and ssi.method = "rao"
FA.AMMI(model, ssi.method = "rao")

# Changing the ratio of weights for Rao's SSI
FA.AMMI(model, ssi.method = "rao", a = 0.43)

# }

Run the code above in your browser using DataLab